@@ -5,7 +5,7 @@ from construct import (Array, Byte, Embedded, Flag, Float32l, If, Int16sl, Int16
                        Switch, Pass, RepeatUntil, Bytes, LazyBound)
 
 from mgz.enums import ObjectEnum, ObjectTypeEnum, ResourceEnum
-from mgz.util import Find
+from mgz.util import Find, Version, find_version
 from mgz.header.unit_type import unit_type
 
 # pylint: disable=invalid-name
@@ -32,8 +32,8 @@ animated_sprite = "animated_sprite"/Struct(
 
 sprite_list = "sprite_list"/Struct(
     "type"/Byte,
-    If(lambda ctx: ctx.type != 0, active_sprite),
-    If(lambda ctx: ctx.type == 2, animated_sprite),
+    "active"/If(lambda ctx: ctx.type != 0, active_sprite),
+    "animated"/If(lambda ctx: ctx.type == 2, animated_sprite),
     Embedded(If(lambda ctx: ctx.type != 0, Struct(
         "order"/Byte,
         "flag"/Byte,
@@ -41,7 +41,6 @@ sprite_list = "sprite_list"/Struct(
     )))
 )
 
-
 static = "static"/Struct(
     "object_type"/Int16ul,
     "sprite"/Int16ul,
@@ -70,8 +69,20 @@ static = "static"/Struct(
     "pathing_group"/Array(lambda ctx: ctx.pathing_group_len, "object_id"/Int32ul),
     "group_id"/Int32sl,
     "roo_already_called"/Byte,
+    "de_static_unk1"/If(lambda ctx: find_version(ctx) == Version.DE, Bytes(19)),
     "has_sprite_list"/Byte,
-    "sprite_list"/If(lambda ctx: ctx.has_sprite_list != 0, RepeatUntil(lambda x,lst,ctx: lst[-1].type == 0, sprite_list))
+    "sprite_list"/If(lambda ctx: ctx.has_sprite_list != 0, RepeatUntil(lambda x,lst,ctx: lst[-1].type == 0, sprite_list)),
+    "de_effect_block"/If(lambda ctx: find_version(ctx) == Version.DE, Struct(
+        Padding(4),
+        "has_effect"/Byte,
+        "effect"/If(lambda ctx: ctx.has_effect == 1, Struct(
+            Padding(3),
+            "length"/Int16ul,
+            "name"/Bytes(lambda ctx: ctx.length),
+            Padding(33)
+        )),
+        Padding(5)
+    ))
 )
 
 
@@ -80,7 +91,6 @@ animated = "animated"/Struct(
     "turn_speed"/Float32l
 )
 
-
 path_data = "path_data"/Struct(
     "id"/Int32ul,
     "linked_path_type"/Int32ul,
@@ -109,7 +119,7 @@ movement_data = "movement"/Struct(
     "acceleration"/vector
 )
 
-moving = "moving"/Struct(
+base_moving = "base_moving"/Struct(
     Embedded(animated),
     "trail_remainder"/Int32ul,
     "velocity"/vector,
@@ -128,6 +138,7 @@ moving = "moving"/Struct(
     "future_path_data"/If(lambda ctx: ctx.has_future_path_data > 0, path_data),
     "has_movement_data"/Int32ul,
     "movement_data"/If(lambda ctx: ctx.has_movement_data > 0, movement_data),
+    "de_moving_unk"/If(lambda ctx: find_version(ctx) == Version.DE, Int16ul),
     "position"/vector,
     "orientation_forward"/vector,
     "orientation_right"/vector,
@@ -139,6 +150,37 @@ moving = "moving"/Struct(
     "consecutive_subsitute_count"/Int32ul
 )
 
+moving = "moving"/Struct(
+    Embedded(base_moving),
+    "de"/If(lambda ctx: find_version(ctx) == Version.DE, Bytes(17))
+)
+
+move_to = "move_to"/Struct(
+    "range"/Float32l
+)
+
+enter = "enter"/Struct(
+    "first_time"/Int32ul
+)
+
+make = "make"/Struct(
+    "work_timer"/Float32l
+)
+
+attack = "attack"/Struct(
+    "range"/Float32l,
+    "min_range"/Float32l,
+    "missile_id"/Int16ul,
+    "frame_delay"/Int16ul,
+    "need_to_attack"/Int16ul,
+    "was_same_owner"/Int16ul,
+    "indirect_fire_flag"/Byte,
+    "move_sprite_id"/Int16ul,
+    "fight_sprite_id"/Int16ul,
+    "wait_sprite_id"/Int16ul,
+    "last_target_position"/vector
+)
+
 unit_action = Struct(
     "type"/Int16ul,
     "data"/If(lambda ctx: ctx.type > 0, Struct(
@@ -154,15 +196,12 @@ unit_action = Struct(
         "sub_action_value"/Byte,
         "sub_actions"/LazyBound(lambda x: action_list),
         "sprite_id"/Int16sl,
-        If(lambda ctx: ctx._.type == 1, Struct(
-            "range"/Float32l
-        )),
-         If(lambda ctx: ctx._.type == 3, Struct(
-            "first_time"/Int32ul
-        )),
-        If(lambda ctx: ctx._.type == 21, Struct(
-            "work_timer"/Float32l
-        ))
+        Embedded("additional"/Switch(lambda ctx: ctx._.type, {
+            1: move_to,
+            3: enter,
+            9: attack,
+            21: make
+        }, default=Pass))
     ))
 )
 
@@ -171,7 +210,7 @@ action_list = "action_list"/Struct(
 )
 
 action = "action"/Struct(
-    Embedded(moving),
+    Embedded(base_moving),
     "waiting"/Byte,
     "command_flag"/Byte,
     "selected_group_info"/Int16ul,
@@ -293,12 +332,14 @@ unit_ai = "ai"/Struct(
     "num_retarget_entries"/Int32ul,
     "retarget_entries"/Array(lambda ctx: ctx.num_retarget_entries, retarget),
     "best_unit_to_attack"/Int32ul,
-    "formation_type"/Byte
+    "formation_type"/Byte,
+    "de_unk"/If(lambda ctx: find_version(ctx) == Version.DE, Bytes(4))
 )
 
 
 combat = "combat"/Struct(
     Embedded(base_combat),
+    "de"/If(lambda ctx: find_version(ctx) == Version.DE, Bytes(18)),
     "next_volley"/Byte,
     "using_special_animation"/Byte,
     "own_base"/Byte,
@@ -310,6 +351,11 @@ combat = "combat"/Struct(
     "inside_garrison_count"/Byte,
     "has_ai"/Int32ul,
     "ai"/If(lambda ctx: ctx.has_ai > 0, unit_ai),
+    "peek"/Peek(Bytes(5)), # TODO: figure out the right way to do this part
+    "de_position"/If(lambda ctx: ctx.peek != b'\x00\xff\xff\xff\xff', Struct(
+        "position"/vector,
+        "flag"/Byte,
+    )),
     "town_bell_flag"/Byte,
     "town_bell_target_id"/Int32sl,
     "town_bell_target_x"/Float32l,
@@ -342,10 +388,10 @@ building = "building"/Struct(
     "desolid_flag"/Byte,
     "pending_order"/Int32ul,
     "linked_owner"/Int32sl,
-    "linked_children"/Array(4, Int32sl),
+    "linked_children"/Array(lambda ctx: 3 if find_version(ctx) == Version.DE else 4, Int32sl),
     "captured_unit_count"/Byte,
     "extra_actions"/action_list,
-    "research_actions"/action_list,
+    "research_actions"/If(lambda ctx: find_version(ctx) != Version.DE, action_list),
     "capacity"/Int16ul,
     "production_queue"/Array(lambda ctx: ctx.capacity, production_queue),
     "size"/Int16ul,
@@ -360,6 +406,7 @@ building = "building"/Struct(
     "terrain_type"/Byte,
     "semi_asleep"/Byte,
     "snow_flag"/Byte,
+    "de_flag_unk"/If(lambda ctx: find_version(ctx) == Version.DE, Byte)
 )
 
 # Objects that exist on the map at the start of the recorded game
